pub enum Token {
UnwrapLiteral(String),
}Expand description
Interpolation token. Different tokens are handled differently:
- UnwrapLiteral: just place original string as is, into source css file. Later can be extended with compile time or runtime expressions.
Variants