pub struct CssOutput { /* private fields */ }Implementations
Sourceimpl CssOutput
impl CssOutput
Sourcepub fn clear_styles(&mut self)
pub fn clear_styles(&mut self)
Removes styles from output.
Sourcepub fn classes_map(&self) -> &BTreeMap<String, ClassInfo>
pub fn classes_map(&self) -> &BTreeMap<String, ClassInfo>
Returns map of changed classes.
Sourcepub fn declare(&self) -> Option<ItemStruct>
pub fn declare(&self) -> Option<ItemStruct>
Returns mod name if css should emit mod instead of inline struct.
Sourcepub fn extend(&self) -> Option<Path>
pub fn extend(&self) -> Option<Path>
Returns path to mod if css should extend existing css in mod instead of creating one from scratch.
pub fn style_string(&self) -> String
pub fn class_name(&self) -> &str
pub fn class_suffix(&self) -> &str
pub fn merge_to_string(styles: &[Self]) -> String